@@ -1,6 +1,5 @@
 // SPDX-FileCopyrightText: 2019-2020 Jonah Brüchert <jbb@kaidan.im>
 // SPDX-FileCopyrightText: 2022 Devin Lin <devin@kde.org>
-//
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include <QApplication>
@@ -14,6 +13,7 @@
 #include <KAboutData>
 
 #include "abouttype.h"
+#include "fontlistmodel.h"
 #include "terminalsettings.h"
 #include "savedcommandsmodel.h"
 #include "terminaltabmodel.h"
@@ -29,6 +29,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     
     QApplication app(argc, argv);
     
+    KLocalizedString::setApplicationDomain("qmlkonsole");
     KAboutData aboutData(QStringLiteral("qmlkonsole"),
                          QStringLiteral("QMLKonsole"),
                          QStringLiteral(QMLKONSOLE_VERSION_STRING),
@@ -58,6 +59,9 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterSingletonType<TerminalTabModel>(URI, 1, 0, "TerminalTabModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return TerminalTabModel::self();
     });
+    qmlRegisterSingletonType<FontListSearchModel>(URI, 1, 0, "FontListSearchModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        return FontListSearchModel::self();
+    });
     qmlRegisterSingletonType<Util>(URI, 1, 0, "Util", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return Util::self();
     });
